@@ -21,11 +21,12 @@ use R::YapRI::Data::Matrix;
 =head1 NAME
 
 R::YapRI::Graph::Simple.pm
+
 A module to create simple graphs using R through R::YapRI::Base
 
 =cut
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 $VERSION = eval $VERSION;
 
 =head1 SYNOPSIS
@@ -66,13 +67,13 @@ $VERSION = eval $VERSION;
     },
   });
 
-  my $block = $rgraph->build_graph();
-  $rgraph->run_graph($block);
+  $rgraph->build_graph('GRAPHBLOCK1');
+  my ($graphfile, $resultfile) = $rgraph->run_graph()
 
 
 =head1 DESCRIPTION
 
-This module is a wrapper of R::YapRI::Base to create simple graphs using R, 
+This module is a wrapper of L<R::YapRI::Base> to create simple graphs using R, 
 with the following features:
 
 1) It loads the data from Perl to R using R::YapRI::Data::Matrix.
@@ -82,16 +83,21 @@ the module/script and use as base to add the data and the graph creation
 commands.
 
 3) It runs the following R commands acording the different accessors:
+
 - device:  bmp, jpeg, tiff, png, postscript or pdf.
+
 - grparam: par.
+
 - sgraph (high-level plotting commands): plot, pairs, hist, dotchart, 
                                          barplot, pie or boxplot.
+
 - gritems (low-level plotting commands): points, lines, abline, polygon, 
                                          legend, title and axis.
 
 4) It uses two commands to create the file with the graph:
 
 + build_graph(), to write into the R::YapRI::Base block the R commands.
+
 + run_graph(), to executate the R commands from the block.
 
 
@@ -1164,13 +1170,17 @@ sub run_graph {
 =head1 ACKNOWLEDGEMENTS
 
 Lukas Mueller
+
 Robert Buels
+
 Naama Menda
+
 Jonathan "Duke" Leto
 
 =head1 COPYRIGHT AND LICENCE
 
 Copyright 2011 Boyce Thompson Institute for Plant Research
+
 Copyright 2011 Sol Genomics Network (solgenomics.net)
 
 This program is free software; you can redistribute it and/or 
